@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: xml-conduit
-version: 1.3.4
-id: xml-conduit-1.3.4-2cb0835929c2dc7743cd241414dfd06a
-key: xmlco_BdGqZPHhDcSCUAiQROoGJX
+version: 1.3.5
+id: xml-conduit-1.3.5-b0d7925ea0f1a62fe18b3cdd25dd3416
+key: xmlco_12KN28fUTcDAD9RoetZ0KS
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -19,24 +19,24 @@ exposed-modules:
     Text.XML.Cursor Text.XML.Cursor.Generic Text.XML
 hidden-modules: Text.XML.Stream.Token
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/xml-conduit-1.3.4
-library-dirs: /usr/lib/ghc-7.10.3/site-local/xml-conduit-1.3.4
-data-dir: /usr/share/arm-linux-ghc-7.10.3/xml-conduit-1.3.4
-hs-libraries: HSxml-conduit-1.3.4-BdGqZPHhDcSCUAiQROoGJX
+import-dirs: /usr/lib/ghc-7.10.3/site-local/xml-conduit-1.3.5
+library-dirs: /usr/lib/ghc-7.10.3/site-local/xml-conduit-1.3.5
+data-dir: /usr/share/arm-linux-ghc-7.10.3/xml-conduit-1.3.5
+hs-libraries: HSxml-conduit-1.3.5-12KN28fUTcDAD9RoetZ0KS
 depends:
-    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
+    attoparsec-0.13.0.2-669cbb29a91e49834657a781d3adc2de
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
-    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
-    blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
+    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
+    blaze-html-0.8.1.1-196db2ddcb827bc04473411dd00dd5eb
+    blaze-markup-0.7.0.3-301d79472dd24aabecf5f1be193f6bdb
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-    conduit-extra-1.1.13.1-9eaf94b1885f7c12e1eeebbc86766f62
+    conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
+    conduit-extra-1.1.13.1-cf2e2742d7d01907ed25c65d155b9a5e
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
+    data-default-0.6.0-4c4f075845d560f7a31d444f67905db9
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
-    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
+    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
+    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     xml-types-0.3.6-d2b0c720c0578e3ecc104b3af950ac90
